[seam-commits] Seam SVN: r14292 - in branches/enterprise/JBPAPP_5_0: examples/itext/view and 4 other directories.

seam-commits at lists.jboss.org seam-commits at lists.jboss.org
Fri Feb 3 04:52:55 EST 2012


Author: manaRH
Date: 2012-02-03 04:52:54 -0500 (Fri, 03 Feb 2012)
New Revision: 14292

Modified:
   branches/enterprise/JBPAPP_5_0/build/root.pom.xml
   branches/enterprise/JBPAPP_5_0/examples/itext/view/index.xhtml
   branches/enterprise/JBPAPP_5_0/src/gen/org/jboss/seam/tool/EclipseClasspathTask.java
   branches/enterprise/JBPAPP_5_0/src/pdf/org/jboss/seam/pdf/ui/UIChart.java
   branches/enterprise/JBPAPP_5_0/src/pdf/org/jboss/seam/pdf/ui/UIChartData.java
   branches/enterprise/JBPAPP_5_0/src/test/ftest/ftest.properties
   branches/enterprise/JBPAPP_5_0/ui/src/main/java/org/jboss/seam/ui/ClientUidSelector.java
Log:
JBPAPP-7183 backed port fix for ClientUidSelector

Modified: branches/enterprise/JBPAPP_5_0/build/root.pom.xml
===================================================================
--- branches/enterprise/JBPAPP_5_0/build/root.pom.xml	2012-02-03 09:15:47 UTC (rev 14291)
+++ branches/enterprise/JBPAPP_5_0/build/root.pom.xml	2012-02-03 09:52:54 UTC (rev 14292)
@@ -15,7 +15,7 @@
 		<version.drools>5.1.0.BRMS</version.drools>
 		<version.testng>5.9</version.testng>
 		<version.resteasy>1.2.1.GA_CP02</version.resteasy>
-		<version.spring>2.5.6.SEC02</version.spring>
+		<version.spring>2.5.6.SEC03</version.spring>
         <version.hibernate-core>3.3.2.GA_CP04</version.hibernate-core>
 	</properties>
 

Modified: branches/enterprise/JBPAPP_5_0/examples/itext/view/index.xhtml
===================================================================
--- branches/enterprise/JBPAPP_5_0/examples/itext/view/index.xhtml	2012-02-03 09:15:47 UTC (rev 14291)
+++ branches/enterprise/JBPAPP_5_0/examples/itext/view/index.xhtml	2012-02-03 09:52:54 UTC (rev 14292)
@@ -45,6 +45,7 @@
         </li>
         <li><s:link view="/swing.xhtml"     value="Swing Component" /></li>
         <li><s:link view="/fillform.xhtml"     value="Fill-in-forms" /></li>
+        <li><s:link view="/piechart.xhtml"     value="Bug in Piechart?" /></li>
 
 
 <ui:remove>

Modified: branches/enterprise/JBPAPP_5_0/src/gen/org/jboss/seam/tool/EclipseClasspathTask.java
===================================================================
--- branches/enterprise/JBPAPP_5_0/src/pdf/org/jboss/seam/pdf/ui/UIChart.java	2012-02-03 09:15:47 UTC (rev 14291)
+++ branches/enterprise/JBPAPP_5_0/src/pdf/org/jboss/seam/pdf/ui/UIChart.java	2012-02-03 09:52:54 UTC (rev 14292)
@@ -342,13 +342,9 @@
     }
 
     @Override
-    public void encodeBegin(FacesContext context) throws IOException {
-        dataset = getDataset();
+    public void encodeBegin(FacesContext context) throws IOException {        
         // bypass super to avoid createITextObject() before the chart is ready
-        if (dataset == null) {
-            dataset = createDataset();
-        }
-        
+        dataset = createDataset();
         chart = getChart();
         if (chart == null) {
             chart = createChart(context);

Modified: branches/enterprise/JBPAPP_5_0/src/pdf/org/jboss/seam/pdf/ui/UIChartData.java
===================================================================
--- branches/enterprise/JBPAPP_5_0/src/pdf/org/jboss/seam/pdf/ui/UIChartData.java	2012-02-03 09:15:47 UTC (rev 14291)
+++ branches/enterprise/JBPAPP_5_0/src/pdf/org/jboss/seam/pdf/ui/UIChartData.java	2012-02-03 09:52:54 UTC (rev 14292)
@@ -141,7 +141,10 @@
 
             if (dataset instanceof DefaultPieDataset) {
                 DefaultPieDataset piedata = (DefaultPieDataset) dataset;
+                System.out.println("Number of items in dataset " + piedata.getItemCount());
+                System.out.println("Adding value " + getNumericValue() + " into dataset " +  getKey() );
                 piedata.setValue(getKey(), getNumericValue());
+                System.out.println("Number of items in dataset " + piedata.getItemCount());
 
                 PiePlot plot = (PiePlot) chart.getChart().getPlot();
 
@@ -165,7 +168,9 @@
 
                 // CategoryPlot plot = (CategoryPlot)
                 // chart.getChart().getPlot();
-                data.addValue(getNumericValue(), getSeries(), getKey());
+                System.out.println("Adding value " + getNumericValue() + " into dataset " + data.getValue(getSeries(), getKey()));
+                data.addValue(getNumericValue(), getSeries(), getKey());  
+                
 //            } else if (dataset instanceof DefaultXYDataset) {
 //              DefaultXYDataset data =   (DefaultXYDataset) dataset;
 

Modified: branches/enterprise/JBPAPP_5_0/src/test/ftest/ftest.properties
===================================================================
--- branches/enterprise/JBPAPP_5_0/src/test/ftest/ftest.properties	2012-02-03 09:15:47 UTC (rev 14291)
+++ branches/enterprise/JBPAPP_5_0/src/test/ftest/ftest.properties	2012-02-03 09:52:54 UTC (rev 14292)
@@ -96,4 +96,6 @@
 test.package=com.example.test
 richfaces.skin=classic
 jboss.domain=default
+openid.account=seamqa.myopenid.com
+openid.password=jboss42
 # ant.exec=/usr/bin/ant

Modified: branches/enterprise/JBPAPP_5_0/ui/src/main/java/org/jboss/seam/ui/ClientUidSelector.java
===================================================================
--- branches/enterprise/JBPAPP_5_0/ui/src/main/java/org/jboss/seam/ui/ClientUidSelector.java	2012-02-03 09:15:47 UTC (rev 14291)
+++ branches/enterprise/JBPAPP_5_0/ui/src/main/java/org/jboss/seam/ui/ClientUidSelector.java	2012-02-03 09:52:54 UTC (rev 14292)
@@ -20,6 +20,9 @@
 @Name("org.jboss.seam.ui.clientUidSelector")
 public class ClientUidSelector extends Selector
 {
+
+   private static final long serialVersionUID = 816459544346114991L;
+
    private String clientUid;
 
    @Create
@@ -34,7 +37,7 @@
    public void seed()
    {
       if (!isSet()) {
-         clientUid = RandomStringUtils.randomAscii(50);
+         clientUid = RandomStringUtils.random(50, true, true);
          setCookieValueIfEnabled(clientUid);
       }
    }



More information about the seam-commits mailing list
--- branches/enterprise/JBPAPP_5_0/src/gen/org/jboss/seam/tool/EclipseClasspathTask.java	2012-02-03 09:15:47 UTC (rev 14291)
+++ branches/enterprise/JBPAPP_5_0/src/gen/org/jboss/seam/tool/EclipseClasspathTask.java	2012-02-03 09:52:54 UTC (rev 14292)
@@ -37,9 +37,10 @@
       
       for (String path : uberPath.list())
       {
-         // avoid placing modules on classpath
-         if (!path.contains("jboss-seam"))
+         // avoid placing modules on classpath and pom files
+         if (!path.contains("jboss-seam") && !path.contains(".pom"))
          {
+            System.out.println("PATH " + path);
             String sourcePath = path.substring(0, path.lastIndexOf(".jar")) + "-sources.jar";
             String javadocPath = path.substring(0, path.lastIndexOf(".jar")) + "-javadoc.jar";
             String eclipsepath = "\t<classpathentry kind=\"lib\" path=\""

Modified: branches/enterprise/JBPAPP_5_0/src/pdf/org/jboss/seam/pdf/ui/UIChart.java
===================================================================